<div dir="rtl">

# پکیج سرویس های مشترک پلتفرم پاد

این پکیج شامل سرویس های زیر است
* سرویس دریافت توکن یکبار مصرف (ott)
* سرویس دریافت لیست ارزها
* سرویس دریافت لیست اصناف
* سرویس مدیریت دسته بندی برچسب های درختی
* سرویس مدیریت برچسب ها

# نصب

برای نصب از طریق `pip` کافیه تا دستور زیر را اجرا کنید
```
pip install pod-common
```


# نمونه کد

نمونه کد ها و مثال هایی از تمام متدهای این پکیج را می توانید 
[اینجا](examples)
پیدا کنید.

</div>